@@ -2,7 +2,7 @@ import requests
 import json
 
 
-header = {'Content-Type': 'application/x-www-form-urlencoded'}
+HEADER = {'Content-Type': 'application/json'}
 
 
 def ret(response):
@@ -12,21 +12,21 @@ def ret(response):
         return response
 
 
-def send_get(url, params=None, headers=header):
+def send_get(url, params=None, headers=HEADER):
     response = requests.get(url=url, params=params, headers=headers)
     return ret(response)
 
 
-def send_post(url, data={}, headers=header):
+def send_post(url, data={}, headers=HEADER):
     response = requests.post(url=url, data=data, headers=headers)
     return ret(response)
 
 
-def send_put(url, data={}, headers=header):
+def send_put(url, data={}, headers=HEADER):
     response = requests.put(url=url, data=data, headers=headers)
     return ret(response)
 
 
-def send_delete(url, data={}, headers=header):
+def send_delete(url, data={}, headers=HEADER):
     response = requests.delete(url=url, data=data, headers=headers)
     return ret(response)
